# 025

|                                                                      | HWFS1015AB      |
|:---------------------------------------------------------------------|:----------------|
| bindTime                                                             | 1694675286314   |
| createTime                                                           | 0               |
| deviceFeatureCode                                                    | 1wj100725v0t    |
| deviceFeatureName                                                    | WFSE1015-LVT001 |
| deviceId                                                             | <redacted>      |
| deviceNickName                                                       | Washing Machine |
| deviceTypeCode                                                       | 025             |
| deviceTypeName                                                       |                 |
| offlineState                                                         | 0               |
| puid                                                                 | <redacted>      |
| role                                                                 | 1               |
| roomId                                                               | 2708438         |
| roomName                                                             | Laundry         |
| seq                                                                  | 0               |
| statusList.Actions                                                   | 0               |
| statusList.AirDryFlag                                                | 0               |
| statusList.AirWashTime                                               | 0               |
| statusList.AntiCrease                                                | 0               |
| statusList.ApplicationPermissions                                    | 2               |
| statusList.AquaPreserve                                              | 0               |
| statusList.AquaPreserve_Flag                                         | 0               |
| statusList.AutoDose                                                  | 0               |
| statusList.AutoTubClean                                              | 0               |
| statusList.BathingWaterPumpState                                     | 0               |
| statusList.BathingWaterPump_Rinse                                    | 0               |
| statusList.BathingWaterPump_Wash                                     | 0               |
| statusList.Cancle_DelayEnd                                           | 0               |
| statusList.Child_lock                                                | 0               |
| statusList.CurrentProgram_High_WaterLevel_InflowTime                 | 0               |
| statusList.CurrentProgram_High_WaterLevel_Starting_WaterLevelValue   | 0               |
| statusList.CurrentProgram_Low_WaterLevel_InflowTime                  | 0               |
| statusList.CurrentProgram_Medium_WaterLevel_InflowTime               | 0               |
| statusList.CurrentProgram_Medium_WaterLevel_Starting_WaterLevelValue | 0               |
| statusList.Current_program_phase                                     | 0               |
| statusList.DefaultSpinSpeed                                          | 14              |
| statusList.Degerming_State                                           | 0               |
| statusList.DelayEndTime                                              | 0               |
| statusList.DelayEndTime_Minute                                       | 0               |
| statusList.Detergent                                                 | 1               |
| statusList.DetergentStandardDosage                                   | 0               |
| statusList.Detergent_display                                         | 1               |
| statusList.Detergent_state                                           | 0               |
| statusList.Door_status                                               | 1               |
| statusList.Dose_Detergent_amount                                     | 1               |
| statusList.Dose_Softener_amount                                      | 1               |
| statusList.DownLight                                                 | 0               |
| statusList.DownLight_LightTime                                       | 0               |
| statusList.DrumCleanCycle_RunsNumber                                 | 0               |
| statusList.DrumCleanFlag                                             | 0               |
| statusList.DrumCleanWashCount                                        | 0               |
| statusList.DryOpen_DefaultSpinSpeed                                  | 14              |
| statusList.DryingSwitch                                              | 0               |
| statusList.EcoMode                                                   | 0               |
| statusList.Electricit_consumption_decimal                            | 19              |
| statusList.Electricit_consumption_int                                | 0               |
| statusList.Energy_estimate                                           | 40              |
| statusList.EnterPerformanceMode_dry1_ConditionType                   | 0               |
| statusList.EnterPerformanceMode_dry1_MainWashTime                    | 0               |
| statusList.EnterPerformanceMode_wash1_ConditionType                  | 0               |
| statusList.EnterPerformanceMode_wash1_MainWashTime                   | 0               |
| statusList.EnterPerformanceMode_wash2_ConditionType                  | 0               |
| statusList.EnterPerformanceMode_wash2_MainWashTime                   | 0               |
| statusList.ExtraRinseNum                                             | 0               |
| statusList.ExtraRinseNum_Flag                                        | 0               |
| statusList.Extra_Rinse                                               | 0               |
| statusList.FlexibleSpinTime_Flag                                     | 1               |
| statusList.Half_Load                                                 | 0               |
| statusList.Hard_pairing_commond                                      | 0               |
| statusList.Hard_pairing_status                                       | 0               |
| statusList.IntensiveWash                                             | 0               |
| statusList.Language                                                  | 0               |
| statusList.Last_completed_running_process                            | 0               |
| statusList.LidOpenFlag                                               | 0               |
| statusList.MainWashTimeList                                          | 0               |
| statusList.MainWashTimeUseIndex                                      | 2               |
| statusList.OnceWaterInRinse_Time                                     | 0               |
| statusList.PowerSaveDeleteTime                                       | 0               |
| statusList.Power_Save                                                | 0               |
| statusList.PreSoak                                                   | 0               |
| statusList.PreSoakFlag                                               | 0               |
| statusList.Prewash                                                   | 0               |
| statusList.Program_end_to_shutdown_time_in_minutes                   | 0               |
| statusList.Quiet_model                                               | 0               |
| statusList.RinseNum                                                  | 3               |
| statusList.RinseNum_ContainExtraRinse                                | 0               |
| statusList.RinseNum_Index                                            | 0               |
| statusList.ScreenSaverTime                                           | 0               |
| statusList.Selected_program_ID                                       | 7               |
| statusList.Selected_program_Water_Add                                | 0               |
| statusList.Selected_program_remaining_time_in_minutes                | 1               |
| statusList.Selected_program_total_running_time_in_minutes            | 1               |
| statusList.Selected_program_total_time_in_minutes                    | 1               |
| statusList.Session_pairing_commond                                   | 0               |
| statusList.Session_pairing_states                                    | 0               |
| statusList.SingleAirDry                                              | 0               |
| statusList.SkipDelayProcess                                          | 0               |
| statusList.Softener                                                  | 1               |
| statusList.Softener_state                                            | 1               |
| statusList.Softer_display                                            | 1               |
| statusList.SoftnerStandardDosage                                     | 0               |
| statusList.SoilLeverFlag                                             | 0               |
| statusList.Soil_Lever                                                | 2               |
| statusList.Sound_setting                                             | 3               |
| statusList.SpinSpeedUseIndex                                         | 0               |
| statusList.Spin_speed_rpm                                            | 10              |
| statusList.Spintime_Index                                            | 0               |
| statusList.Stain_removal                                             | 0               |
| statusList.StandardElectricitConsumption_int                         | 0               |
| statusList.StandardElectricitconsumption_decimal                     | 0               |
| statusList.StandardWaterConsumption_decimal                          | 0               |
| statusList.StandardWaterConsumption_int                              | 0               |
| statusList.Steam                                                     | 0               |
| statusList.Temp_Index                                                | 0               |
| statusList.Temp_wave                                                 | 0               |
| statusList.Temp_wave_flag                                            | 0               |
| statusList.Temperature_0_DefaultMainWashTime                         | 0               |
| statusList.Temperature_2_DefaultMainWashTime                         | 0               |
| statusList.Temperature_3_DefaultMainWashTime                         | 0               |
| statusList.Temperature_4_DefaultMainWashTime                         | 0               |
| statusList.Temperature_6_DefaultMainWashTime                         | 0               |
| statusList.Temperature_9_DefaultMainWashTime                         | 0               |
| statusList.Temperature_Default_DefaultMainWashTime                   | 140             |
| statusList.Testdata_data                                             | 0               |
| statusList.Testdata_month                                            | 0               |
| statusList.Testdata_year                                             | 0               |
| statusList.Time_Save                                                 | 0               |
| statusList.UV_Light                                                  | 0               |
| statusList.WarmWaterWashing                                          | 0               |
| statusList.WashingTimeIndex                                          | 0               |
| statusList.WashingWizzard_Cloth                                      | 0               |
| statusList.WashingWizzard_Cloth_colour                               | 0               |
| statusList.WashingWizzard_Cloth_colour_fifth                         | 0               |
| statusList.WashingWizzard_Cloth_colour_fourth                        | 0               |
| statusList.WashingWizzard_Cloth_colour_second                        | 0               |
| statusList.WashingWizzard_Cloth_colour_third                         | 0               |
| statusList.WashingWizzard_Cloth_dirty                                | 0               |
| statusList.WashingWizzard_Cloth_dirty_first                          | 0               |
| statusList.WashingWizzard_Cloth_dirty_second                         | 0               |
| statusList.WashingWizzard_Cloth_dirty_third                          | 0               |
| statusList.WashingWizzard_Cloth_olour_first                          | 0               |
| statusList.WashingWizzard_Cloth_sensitive                            | 0               |
| statusList.WashingWizzard_Cloth_sensitive_first                      | 0               |
| statusList.WashingWizzard_Cloth_sensitive_second                     | 0               |
| statusList.WashingWizzard_Cloth_sensitive_third                      | 0               |
| statusList.WashingWizzard_Cloth_stains_eighth                        | 0               |
| statusList.WashingWizzard_Cloth_stains_fifth                         | 0               |
| statusList.WashingWizzard_Cloth_stains_first                         | 0               |
| statusList.WashingWizzard_Cloth_stains_fourth                        | 0               |
| statusList.WashingWizzard_Cloth_stains_ninth                         | 0               |
| statusList.WashingWizzard_Cloth_stains_second                        | 0               |
| statusList.WashingWizzard_Cloth_stains_seventh                       | 0               |
| statusList.WashingWizzard_Cloth_stains_sixth                         | 0               |
| statusList.WashingWizzard_Cloth_stains_third                         | 0               |
| statusList.WashingWizzard_ClothingType                               | 0               |
| statusList.WashingWizzard_ClothingType_eighth                        | 0               |
| statusList.WashingWizzard_ClothingType_eleventh                      | 0               |
| statusList.WashingWizzard_ClothingType_fifth                         | 0               |
| statusList.WashingWizzard_ClothingType_first                         | 0               |
| statusList.WashingWizzard_ClothingType_fourth                        | 0               |
| statusList.WashingWizzard_ClothingType_ninth                         | 0               |
| statusList.WashingWizzard_ClothingType_second                        | 0               |
| statusList.WashingWizzard_ClothingType_seventh                       | 0               |
| statusList.WashingWizzard_ClothingType_sixth                         | 0               |
| statusList.WashingWizzard_ClothingType_tenth                         | 0               |
| statusList.WashingWizzard_ClothingType_third                         | 0               |
| statusList.WashingWizzard_ClothingType_thirteenth                    | 0               |
| statusList.WashingWizzard_ClothingType_twelfth                       | 0               |
| statusList.WashingWizzard_flag                                       | 0               |
| statusList.Washing_drying_linkage_flag                               | 0               |
| statusList.Washing_drying_linkage_state                              | 0               |
| statusList.WaterLevel                                                | 0               |
| statusList.WaterLevelFlag                                            | 0               |
| statusList.WaterLevelIndex                                           | 0               |
| statusList.Water_consumption_decimal                                 | 6               |
| statusList.Water_consumption_int                                     | 67              |
| statusList.Water_hardness_setting                                    | 0               |
| statusList.WindDrying                                                | 0               |
| statusList.WindDryingFlag                                            | 0               |
| statusList.add_clothes_check                                         | 0               |
| statusList.daily_energy_kwh                                          | 0               |
| statusList.delay_actions_flag                                        | 0               |
| statusList.dry_lever                                                 | 0               |
| statusList.dry_time                                                  | 0               |
| statusList.error_code                                                | 0               |
| statusList.machine_status                                            | 0               |
| statusList.mian_wash_time                                            | 34              |
| statusList.mute                                                      | 0               |
| statusList.once strong step time                                     | 0               |
| statusList.once_rinse_step_time                                      | 14              |
| statusList.order_time_minimum_hour                                   | 1               |
| statusList.parse_lib_ver                                             | 20240412        |
| statusList.spin_time                                                 | 0               |
| statusList.stoprunning_flag                                          | 0               |
| statusList.temp_runing_flag                                          | 0               |
| statusList.temperature                                               | 3               |
| statusList.time_autoflag                                             | 0               |
| statusList.timezone                                                  | 0               |
| statusList.washFunction1                                             | 0               |
| statusList.wash_step_time_drain_water_spin_and_stop                  | 8               |
| statusList.washing_machine_type                                      | 0               |
| statusList.washing_machine_type_kg                                   | 24              |
| statusList.washing_machine_type_max_speed                            | 14              |
| statusList.washingtime                                               | 0               |
| statusList.waterlevel_runing_flag                                    | 0               |
| useTime                                                              | 1694675286293   |
| wifiId                                                               | <redacted>      |

## Generated from

- [`HWFS1015AB.json`](HWFS1015AB.json)
